==> srinadhch07-0.6.tar.gz: srinadhch07-0.6/README.md <==
![image](https://brunda1.odoo.com/web/image/website/1/logo/MakeItSimple?unique=14c3757)

[![image](https://flat.badgen.net/github/stars/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/stargazers) [![image](https://flat.badgen.net/github/forks/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/network/members)
[![image](https://flat.badgen.net/github/open-issues/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/issues)
[![image](https://flat.badgen.net/github/open-prs/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/pulls)
[![image](https://flat.badgen.net/github/commits/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/commits/master)
[![image](https://flat.badgen.net/github/license/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/LICENCE)
[![image](https://flat.badgen.net/github/contributors/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/graphs/contributors)
[![image](https://flat.badgen.net/github/release/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/releases)
<!-- ![logo](https://github.com/Srinadhch07/BAv2/raw/master/Images/logo.png?raw=true) -->



[BAv2](https://pypi.org/project/srinadhch07/) is a Python library with various helpful features. It's easy-to-use and does not require you to do any additional setup. Currently, it is one of the most popular library for Personal Assistant for user and developers of python. New updates are released frequently with new features and bug fixes.

# Links

- **Join me at Linkedin - https://www.linkedin.com/in/srinadh-ch-887550232/**
- **Documentation - [Wiki](https://github.com/Srinadhch07/BAv2/wiki)**

## Installation and Supported Versions

BAv2 is available on PyPi:

```bash
pip install srinadhch07
```

```bash
pip install srinadhch07==0.3
```

BAv2 officially supports Python 3.8+.

## Cloning the Repository

```bash
git clone https://github.com/Srinadhch07/BAv2.git
```
## What's new in v2.0?
```
Now this current version is integreted with google geminiai
```
## What's new in v2.1?
```py
from srinadhch07.BAv2G import chatG
chatG()
```
## Requirements
```bash

pip install -q -U google-generativeai

```
### This method can be used to use an assistant which provides more features then previous version.
- Make sure your PC installed all the necessary modules before running CMD  based application.
- You can also type and scroll too, enjoy.
- More information here https://github.com/Srinadhch07/BAv2.git with the raw code.

## Features

- This BAv2 provides more personlised responses when compared to previous version
- Still You can use previous version and present version as per users convenience
- BAv2 and BAvG both are compitable for both online and offline environments

## Usage

```py
from srinadhch07.BAv2 import chatbot
from srinadhch07.BAv2G import chatG
#To start working with BAv2 
chatbot()
#to start work with BAv2G
chatG()
```

For more Examples and Functions, have a look at the [Wiki](https://github.com/Srinadhch07/BAv2/wiki).

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.
Be sure to read the [Guidelines](https://github.com/Srinadhch07/BAv2/blob/master/CONTRIBUTING.md) before Contributing.

## License

MIT.
For more information see [this](https://github.com/Srinadhch07/BAv2/blob/master/LICENSE)

==> srinadhch07-0.7.tar.gz: srinadhch07-0.7/README.md <==
![image](https://brunda1.odoo.com/web/image/website/1/logo/MakeItSimple?unique=14c3757)

[![image](https://flat.badgen.net/github/stars/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/stargazers) [![image](https://flat.badgen.net/github/forks/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/network/members)
[![image](https://flat.badgen.net/github/open-issues/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/issues)
[![image](https://flat.badgen.net/github/open-prs/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/pulls)
[![image](https://flat.badgen.net/github/commits/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/commits/master)
[![image](https://flat.badgen.net/github/license/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/LICENCE)
[![image](https://flat.badgen.net/github/contributors/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/graphs/contributors)
[![image](https://flat.badgen.net/github/release/Srinadhch07/BAv2)](https://github.com/Srinadhch07/BAv2/releases)
<!-- ![logo](https://github.com/Srinadhch07/BAv2/raw/master/Images/logo.png?raw=true) -->



[BAv2](https://pypi.org/project/srinadhch07/) is a Python library with various helpful features. It's easy-to-use and does not require you to do any additional setup. Currently, it is one of the most popular library for Personal Assistant for user and developers of python. New updates are released frequently with new features and bug fixes.

# Links

- **Join me at Linkedin - https://www.linkedin.com/in/srinadh-ch-887550232/**
- **Documentation - [Wiki](https://github.com/Srinadhch07/BAv2/wiki)**

## Installation and Supported Versions

BAv2 is available on PyPi:

```bash
pip install srinadhch07
```

```bash
pip install srinadhch07==0.5
```

BAv2 officially supports Python 3.8+.

## Cloning the Repository

```bash
git clone https://github.com/Srinadhch07/BAv2.git
```
## What's new in v2.0?
```
Now this current version is integreted with google geminiai
```
## What's new in v2.1?
```py
from srinadhch07.BAv2G import chatbot
chatbot()
```
## Requirements
```bash

pip install -q -U google-generativeai

```
### This method can be used to use an assistant which provides more features then previous version.
- Make sure your PC installed all the necessary modules before running CMD  based application.
- You can also type and scroll too, enjoy.
- More information here https://github.com/Srinadhch07/BAv2.git with the raw code.

## Features

- This BAv2 provides more personlised responses when compared to previous version
- Still You can use previous version and present version as per users convenience
- BAv2 and BAvG both are compitable for both online and offline environments

## Usage

```py
from srinadhch07.BAv2 import chatbot
#To start working with BAv2 
chatbot()
```

For more Examples and Functions, have a look at the [Wiki](https://github.com/Srinadhch07/BAv2/wiki).

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.
Be sure to read the [Guidelines](https://github.com/Srinadhch07/BAv2/blob/master/CONTRIBUTING.md) before Contributing.

## License

MIT.
For more information see [this](https://github.com/Srinadhch07/BAv2/blob/master/LICENSE)
